/*2:*/
#line 36 "types.web"

typedef struct _STRING *STRING;

/*:2*//*3:*/
#line 41 "types.web"

#ifndef False
typedef enum{False,True}Boolean;
#endif

/*:3*//*4:*/
#line 111 "types.web"

#line 112 "types.web"
typedef enum{Undefined,Proc,Var,Type,Def,Incl,Trans}DeclTp;
typedef struct _Decl{
DeclTp tp;
int lineno;
STRING class_id;
STRING typesym,type;
STRING namesym,name;
STRING suffix;
STRING valuesym,value;
struct _Decl *params;
STRING body;
struct _Decl *next;
} *Decl;

/*:4*//*5:*/
#line 130 "types.web"

#line 131 "types.web"
typedef struct _Section{
STRING text;
Decl decl;
struct _Section *next;
} *Section;

/*:5*//*6:*/
#line 141 "types.web"

#line 142 "types.web"
typedef struct _Option{
STRING opt,val;
struct _Option *next;
} *Option;

/*:6*//*7:*/
#line 152 "types.web"

#line 153 "types.web"
typedef struct _Class{
int lineno;
STRING name,superclass,filename;
Option options;
STRING text;
Section classvars,publicvars,privatevars,methods,actions,
translations,imports,exports,utilities,
constraints,privconstr;
struct _Class *daughters, *sister, *super;
struct _Class *next;
} *Class;

/*:7*/
